==> myfaces-tobago-5.11.0-source-release.zip: tobago-5.11.0/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/ExceptionController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import javax.enterprise.context.RequestScoped;
import javax.faces.context.FacesContext;
import javax.inject.Named;
import java.io.PrintWriter;
import java.io.Serializable;
import java.io.StringWriter;

@RequestScoped
@Named
public class ExceptionController implements Serializable {

  private boolean returnNpe;

  public String getStackTrace() {
    final Throwable exception = (Throwable) FacesContext.getCurrentInstance().getExternalContext()
        .getRequestMap().get("javax.servlet.error.exception");
    final StringWriter stringWriter = new StringWriter();
    final PrintWriter printWriter = new PrintWriter(stringWriter);
    if (exception != null) {
      exception.printStackTrace(printWriter);
    }
    return stringWriter.toString();
  }

  public String getStringOrNpe() {
    if (returnNpe) {
      throw new NullPointerException("The exception is thrown by purpose.");
    }
    return "no NPE";
  }

  public void returnNpe() {
    returnNpe = true;
  }
}

==> myfaces-tobago-6.8.0-source-release.zip: tobago-6.8.0/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/ExceptionController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import jakarta.enterprise.context.RequestScoped;
import jakarta.faces.context.FacesContext;
import jakarta.inject.Named;

import java.io.PrintWriter;
import java.io.Serializable;
import java.io.StringWriter;

@RequestScoped
@Named
public class ExceptionController implements Serializable {

  private boolean returnNpe;

  public String getStackTrace() {
    final Throwable exception = (Throwable) FacesContext.getCurrentInstance().getExternalContext()
        .getRequestMap().get("jakarta.servlet.error.exception");
    final StringWriter stringWriter = new StringWriter();
    final PrintWriter printWriter = new PrintWriter(stringWriter);
    if (exception != null) {
      exception.printStackTrace(printWriter);
    }
    return stringWriter.toString();
  }

  public String getStringOrNpe() {
    if (returnNpe) {
      throw new NullPointerException("The exception is thrown by purpose.");
    }
    return "no NPE";
  }

  public void returnNpe() {
    returnNpe = true;
  }
}
